@@ -74,7 +74,10 @@ AtCore::AtCore(QObject *parent) :
     d->tempTimer->setInterval(5000);
     d->tempTimer->setSingleShot(false);
 
-    for (const auto &path : AtCoreDirectories::pluginDir) {
+    QStringList pathList = AtCoreDirectories::pluginDir;
+    pathList.append(QLibraryInfo::location(QLibraryInfo::PluginsPath) + QStringLiteral("/AtCore"));
+
+    for (const auto &path : pathList) {
         qCDebug(ATCORE_PLUGIN) << "Lookin for plugins in " << path;
         if (QDir(path).exists()) {
             d->pluginsDir = QDir(path);
@@ -612,3 +615,12 @@ QStringList AtCore::portSpeeds() const
 {
     return serial()->validBaudRates();
 }
+
+void AtCore::setIdleHold(uint delay)
+{
+    if (delay != 0) {
+        pushCommand(GCode::toCommand(GCode::M84, QString::number(delay)));
+    } else {
+        pushCommand(GCode::toCommand(GCode::M84));
+    }
+}
